@@ -3,7 +3,26 @@ package Dist::Zilla::PluginBundle::TestingMania;
 use strict;
 use warnings;
 use 5.0100; # We use the smart match operator
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
+
+use Dist::Zilla::Plugin::Test::CPAN::Changes    qw();
+use Dist::Zilla::Plugin::CheckChangesTests      qw();
+use Dist::Zilla::Plugin::CompileTests           qw();
+use Dist::Zilla::Plugin::ConsistentVersionTest  qw();
+use Dist::Zilla::Plugin::CriticTests            qw();
+use Dist::Zilla::Plugin::DistManifestTests      qw();
+use Dist::Zilla::Plugin::EOLTests               qw();
+use Dist::Zilla::Plugin::HasVersionTests        qw();
+use Dist::Zilla::Plugin::KwaliteeTests          qw();
+use Dist::Zilla::Plugin::MetaTests              qw();
+use Dist::Zilla::Plugin::MinimumVersionTests    qw();
+use Dist::Zilla::Plugin::NoTabsTests            qw();
+use Dist::Zilla::Plugin::PodCoverageTests       qw();
+use Dist::Zilla::Plugin::PodSyntaxTests         qw();
+use Dist::Zilla::Plugin::PortabilityTests       qw();
+use Dist::Zilla::Plugin::ProgCriticTests        qw();
+use Dist::Zilla::Plugin::SynopsisTests          qw();
+use Dist::Zilla::Plugin::UnusedVarsTests        qw();
 
 
 use Moose;
@@ -13,7 +32,7 @@ sub configure {
     my $self = shift;
 
     my %plugins = (
-        ChangesTests            => 1,
+        'Test::CPAN::Changes'   => 1,
         CheckChangesTests       => 0, # Finnicky and annoying
         CompileTests            => 1,
         ConsistentVersionTest   => 0, # Finnicky and annoying
@@ -42,7 +61,7 @@ sub configure {
             $plugin ~~ @include or  # plugins we already included
             !$plugins{$plugin}      # plugins in the list, but which we don't want to add
         );
-        if ($plugin eq 'ChangesTests') {
+        if ($plugin eq 'Test::CPAN::Changes') {
             push(@include, [ $plugin => { changelog => ($self->payload->{changelog} || 'Changes') } ])
                 unless $plugin ~~ @include or $plugin ~~ @skip;
             next SKIP;
@@ -75,7 +94,7 @@ Dist::Zilla::PluginBundle::TestingMania - test your dist with every testing plug
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 DESCRIPTION
 
@@ -201,7 +220,7 @@ variables. See L<Test::Vars> for details.
 
 =item *
 
-L<Dist::Zilla::Plugin::ChangesTests>, which checks your changelog for conformance
+L<Dist::Zilla::Plugin::Test::CPAN::Changes>, which checks your changelog for conformance
 with L<CPAN::Changes::Spec>. See L<Test::CPAN::Changes> for details.
 
 =back
